==> medialibrary-0.1.7.tar.gz: medialibrary-0.1.7/src/media/fileops/filenames.py <==
#!/usr/bin/env python

#
# Copyright 2023 Chris Josephes
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#

'''Filename matching for the directory walker'''

# pylint: disable=too-few-public-methods

import re


class FilenameMatches():
    '''Static data on filename matches'''
    Movie_Media = re.compile("-(dvd|bluray|bluray3d|ultrahd|vhs)" +
                             "(-[\\d+])?\\.xml$")
    All_Media_Xml = re.compile("-(dvd|bluray|bluray3d|ultrahd|vhs)" +
                               "(-[\\d+])?\\.xml$")
    All_Xml = re.compile("\\.xml$")

==> medialibrary-0.2.9.tar.gz: medialibrary-0.2.9/src/media/fileops/filenames.py <==
#!/usr/bin/env python

#
# Copyright 2024 Chris Josephes
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#

'''Filename matching for the directory walker'''

# pylint: disable=too-few-public-methods

import re


class FilenameMatches():
    '''Static data on filename matches'''
    Movie_Media = re.compile("-(dvd|bluray|bluray3d|ultrahd|vhs)" +
                             "(-[\\d+])?\\.xml$")
    Music_Media = re.compile("-(audiocd|record)" + "(-[\\d+])?\\.xml$")
    All_Media = re.compile("-(dvd|bluray|bluray3d|ultrahd|vhs|" +
                           "audiocd|record)" +
                           "(-[\\d+])?\\.xml$")
    All_Xml = re.compile("\\.xml$")
